@@ -64,8 +64,11 @@ require DynaLoader;
 
 use vars qw{$VERSION @ISA @EXPORT_OK %EXPORT_TAGS};
 
-$VERSION   = '0.38';
-@ISA       = ('Exporter', 'DynaLoader');
+$VERSION   = '1.00';
+@ISA       = qw{
+	Exporter
+	DynaLoader
+};
 @EXPORT_OK = qw{
 	_STRING     _IDENTIFIER
 	_CLASS      _CLASSISA   _SUBCLASS  _DRIVER
@@ -77,7 +80,7 @@ $VERSION   = '0.38';
 	_INVOCANT   _REGEX      _INSTANCE
 	_SET        _SET0
 	_HANDLE
-	};
+};
 %EXPORT_TAGS = ( ALL => \@EXPORT_OK );
 
 eval {
@@ -543,10 +546,11 @@ END_PERL
 
 =head2 _INVOCANT $value
 
-This routine tests whether the given value is a valid method invocant. This can
-be either an instance of an object, or a class name.
+This routine tests whether the given value is a valid method invocant.
+This can be either an instance of an object, or a class name.
 
-If so, the value itself is returned.  Otherwise, C<_INVOCANT> returns C<undef>.
+If so, the value itself is returned.  Otherwise, C<_INVOCANT>
+returns C<undef>.
 
 =cut
 
@@ -663,8 +667,6 @@ END_PERL
 
 =head2 _HANDLE
 
-B<EXPERIMENTAL: SUBJECT TO CHANGE OR POSSIBLE REMOVAL>
-
 The C<_HANDLE> function is intended to be imported into your package,
 and provides a convenient way to test whether or not a single scalar
 value is a file handle.
@@ -744,8 +746,6 @@ END_PERL
     ...
   }
 
-B<EXPERIMENTAL: SUBJECT TO CHANGE OR POSSIBLE REMOVAL>
-
 The C<_DRIVER> function is intended to be imported into your
 package, and provides a convenient way to load and validate
 a driver class.
